@@ -149,7 +149,7 @@ static msg_t check_vector_props(SEXP x, SEXP any_missing, SEXP all_missing, SEXP
 
 static msg_t check_matrix_props(SEXP x, SEXP any_missing, SEXP min_rows, SEXP min_cols, SEXP rows, SEXP cols) {
     if (!isNull(min_rows) || !isNull(rows)) {
-        R_len_t xrows = nrows(x);
+        R_len_t xrows = get_nrows(x);
         if (!isNull(min_rows)) {
             R_len_t cmp = asCount(min_rows, "min.rows");
             if (xrows < cmp)
@@ -158,11 +158,11 @@ static msg_t check_matrix_props(SEXP x, SEXP any_missing, SEXP min_rows, SEXP mi
         if (!isNull(rows)) {
             R_len_t cmp = asCount(rows, "rows");
             if (xrows != cmp)
-                return Msgf("Must have at exactly %i rows", cmp);
+                return Msgf("Must have exactly %i rows", cmp);
         }
     }
     if (!isNull(min_cols) || !isNull(cols)) {
-        R_len_t xcols = ncols(x);
+        R_len_t xcols = get_ncols(x);
         if (!isNull(min_cols)) {
             R_len_t cmp = asCount(min_cols, "min.cols");
             if (xcols < cmp)
@@ -171,7 +171,7 @@ static msg_t check_matrix_props(SEXP x, SEXP any_missing, SEXP min_rows, SEXP mi
         if (!isNull(cols)) {
             R_len_t cmp = asCount(cols, "cols");
             if (xcols != cmp)
-                return Msgf("Must have at exactly %i cols", cmp);
+                return Msgf("Must have exactly %i cols", cmp);
         }
     }
 
