@@ -1,6 +1,11 @@
 context("checkLogical")
 
 test_that("checkLogical", {
+  myobj = TRUE
+  expect_succ(Logical, myobj)
+  myobj = 1
+  expect_fail(Logical, myobj)
+
   expect_true(testLogical(logical(0)))
   expect_false(testLogical(NULL))
   expect_true(testLogical(TRUE))
@@ -12,6 +17,5 @@ test_that("checkLogical", {
   expect_false(testLogical(iris))
   expect_true(testLogical(c(TRUE, FALSE), min.len = 2))
 
-  expect_true(assertLogical(TRUE))
-  expect_error(assertLogical(1))
+  expect_error(assertLogical(1), "logical")
 })
